# WEnux

WEnux is a Python utility to emulate WAN environment on local machine

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install WEnux.

```bash
pip3 install wenux
```

## Usage

To start graphical user interface one has to initialize it with 2 interfaces between which traffic will be emulated
```bash
sudo ./wenux.py interface1 interface2
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[GPLv3](https://choosealicense.com/licenses/gpl-3.0/)